"use strict";Object.defineProperty(exports, "__esModule", {value: true});// src/index.ts
var _eslint = require('eslint');
var _pluginutils = require('@rollup/pluginutils');

// src/utils.ts


var _querystring = require('querystring');



var _path = require('path');
function normalizePath(id) {
  return _path.relative.call(void 0, process.cwd(), id).split(_path.sep).join("/");
}
function checkVueFile(id) {
  if (!id.includes("?"))
    return false;
  const rawQuery = id.split("?", 2)[1];
  return _querystring.parse.call(void 0, rawQuery).vue !== null ? true : false;
}

// src/index.ts
function eslintPlugin(options) {
  const defaultOptions = {
    cache: true,
    fix: false
  };
  const opts = options ? {...defaultOptions, ...options} : defaultOptions;
  const eslint = new (0, _eslint.ESLint)({
    cache: opts.cache,
    fix: opts.fix
  });
  const filter = _pluginutils.createFilter.call(void 0, opts.include, opts.exclude || /node_modules/);
  let formatter;
  return {
    name: "vite:eslint",
    async transform(_, id) {
      const file = normalizePath(id);
      if (!filter(id) || await eslint.isPathIgnored(file) || checkVueFile(id)) {
        return null;
      }
      switch (typeof opts.formatter) {
        case "string":
          formatter = await eslint.loadFormatter(opts.formatter);
          break;
        case "function":
          ({formatter} = opts);
          break;
        default:
          formatter = await eslint.loadFormatter("stylish");
      }
      const report = await eslint.lintFiles(file);
      const hasWarnings = report.some((item) => item.warningCount !== 0);
      const hasErrors = report.some((item) => item.errorCount !== 0);
      const result = formatter.format(report);
      if (opts.fix && report) {
        _eslint.ESLint.outputFixes(report);
      }
      if (hasWarnings) {
        this.warn(result);
      }
      if (hasErrors) {
        this.error(result);
      }
      return null;
    }
  };
}


exports.default = eslintPlugin;
